==> telepathy-glib-0.19.0.tar.gz: telepathy-glib-0.19.0/telepathy-glib/telepathy-glib.h <==
/*
 * telepathy-glib.h - Headers for telepathy-glib
 *
 * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TP_GLIB_H__
#define __TP_GLIB_H__
#define __TP_IN_GLIB_H__

#include <telepathy-glib/enums.h>
#include <telepathy-glib/errors.h>
#include <telepathy-glib/util.h>
#include <telepathy-glib/gnio-util.h>
#include <telepathy-glib/defs.h>
#include <telepathy-glib/intset.h>
#include <telepathy-glib/heap.h>

#include <telepathy-glib/account-channel-request.h>
#include <telepathy-glib/account-manager.h>
#include <telepathy-glib/account.h>
#include <telepathy-glib/add-dispatch-operation-context.h>
#include <telepathy-glib/automatic-client-factory.h>
#include <telepathy-glib/base-call-channel.h>
#include <telepathy-glib/base-call-content.h>
#include <telepathy-glib/base-call-stream.h>
#include <telepathy-glib/base-channel.h>
#include <telepathy-glib/base-client.h>
#include <telepathy-glib/base-connection-manager.h>
#include <telepathy-glib/base-connection.h>
#include <telepathy-glib/base-contact-list.h>
#include <telepathy-glib/base-media-call-channel.h>
#include <telepathy-glib/base-media-call-content.h>
#include <telepathy-glib/base-media-call-stream.h>
#include <telepathy-glib/base-password-channel.h>
#include <telepathy-glib/base-protocol.h>
#include <telepathy-glib/base-room-config.h>
#include <telepathy-glib/call-channel.h>
#include <telepathy-glib/call-content-media-description.h>
#include <telepathy-glib/call-content.h>
#include <telepathy-glib/call-misc.h>
#include <telepathy-glib/call-stream-endpoint.h>
#include <telepathy-glib/call-stream.h>
#include <telepathy-glib/capabilities.h>
#include <telepathy-glib/channel-dispatch-operation.h>
#include <telepathy-glib/channel-dispatcher.h>
#include <telepathy-glib/channel-iface.h>
#include <telepathy-glib/channel-manager.h>
#include <telepathy-glib/channel-request.h>
#include <telepathy-glib/channel.h>
#include <telepathy-glib/client.h>
#include <telepathy-glib/client-message.h>
#include <telepathy-glib/cm-message.h>
#include <telepathy-glib/connection-contact-list.h>
#include <telepathy-glib/connection-manager.h>
#include <telepathy-glib/connection.h>
#include <telepathy-glib/contact-operations.h>
#include <telepathy-glib/contact-search-result.h>
#include <telepathy-glib/contact-search.h>
#include <telepathy-glib/contact.h>
#include <telepathy-glib/contacts-mixin.h>
#include <telepathy-glib/dbus.h>
#include <telepathy-glib/dbus-properties-mixin.h>
#include <telepathy-glib/dbus-tube-channel.h>
#include <telepathy-glib/debug-client.h>
#include <telepathy-glib/debug-message.h>
#include <telepathy-glib/debug-sender.h>
#include <telepathy-glib/debug.h>
#include <telepathy-glib/dtmf.h>
#include <telepathy-glib/exportable-channel.h>
#include <telepathy-glib/file-transfer-channel.h>
#include <telepathy-glib/group-mixin.h>
#include <telepathy-glib/handle-channels-context.h>
#include <telepathy-glib/handle-repo.h>
#include <telepathy-glib/handle-repo-dynamic.h>
#include <telepathy-glib/handle-repo-static.h>
#include <telepathy-glib/handle.h>
#include <telepathy-glib/media-interfaces.h>
#include <telepathy-glib/message.h>
#include <telepathy-glib/message-mixin.h>
#include <telepathy-glib/observe-channels-context.h>
#include <telepathy-glib/presence-mixin.h>
#include <telepathy-glib/protocol.h>
#include <telepathy-glib/proxy.h>
#include <telepathy-glib/room-info.h>
#include <telepathy-glib/room-list.h>
#include <telepathy-glib/run.h>
#include <telepathy-glib/signalled-message.h>
#include <telepathy-glib/simple-approver.h>
#include <telepathy-glib/simple-client-factory.h>
#include <telepathy-glib/simple-handler.h>
#include <telepathy-glib/simple-password-manager.h>
#include <telepathy-glib/simple-observer.h>
#include <telepathy-glib/stream-tube-channel.h>
#include <telepathy-glib/stream-tube-connection.h>
#include <telepathy-glib/text-channel.h>
#include <telepathy-glib/tls-certificate.h>

/* deprecated, gone in 1.0 */
#include <telepathy-glib/automatic-proxy-factory.h>
#include <telepathy-glib/basic-proxy-factory.h>
#include <telepathy-glib/channel-iface.h>
#include <telepathy-glib/client-channel-factory.h>

/* D-Bus-API-dependent, moved to telepathy-glib-dbus.h in 1.0 */
#include <telepathy-glib/gtypes.h>
#include <telepathy-glib/interfaces.h>
#include <telepathy-glib/svc-generic.h>
#include <telepathy-glib/svc-client.h>

#undef  __TP_IN_GLIB_H__
#endif /* __TP_GLIB_H__ */

==> telepathy-glib-0.99.11.tar.gz: telepathy-glib-0.99.11/telepathy-glib/telepathy-glib.h <==
/*
 * telepathy-glib.h - Headers for telepathy-glib
 *
 * Copyright (C) 2009 Collabora Ltd. <http://www.collabora.co.uk/>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 */

#ifndef __TP_GLIB_H__
#define __TP_GLIB_H__

#define _TP_GLIB_H_INSIDE

#include <telepathy-glib/enums.h>
#include <telepathy-glib/errors.h>
#include <telepathy-glib/util.h>
#include <telepathy-glib/gnio-unix.h>
#include <telepathy-glib/defs.h>
#include <telepathy-glib/intset.h>
#include <telepathy-glib/heap.h>

#include <telepathy-glib/account-channel-request.h>
#include <telepathy-glib/account-manager.h>
#include <telepathy-glib/account-request.h>
#include <telepathy-glib/account.h>
#include <telepathy-glib/add-dispatch-operation-context.h>
#include <telepathy-glib/automatic-client-factory.h>
#include <telepathy-glib/base-call-channel.h>
#include <telepathy-glib/base-call-content.h>
#include <telepathy-glib/base-call-stream.h>
#include <telepathy-glib/base-channel.h>
#include <telepathy-glib/base-client.h>
#include <telepathy-glib/base-connection-manager.h>
#include <telepathy-glib/base-connection.h>
#include <telepathy-glib/base-contact-list.h>
#include <telepathy-glib/base-media-call-channel.h>
#include <telepathy-glib/base-media-call-content.h>
#include <telepathy-glib/base-media-call-stream.h>
#include <telepathy-glib/base-password-channel.h>
#include <telepathy-glib/base-protocol.h>
#include <telepathy-glib/base-room-config.h>
#include <telepathy-glib/call-channel.h>
#include <telepathy-glib/call-content-media-description.h>
#include <telepathy-glib/call-content.h>
#include <telepathy-glib/call-stream-endpoint.h>
#include <telepathy-glib/call-stream.h>
#include <telepathy-glib/capabilities.h>
#include <telepathy-glib/channel-dispatch-operation.h>
#include <telepathy-glib/channel-dispatcher.h>
#include <telepathy-glib/channel-filter.h>
#include <telepathy-glib/channel-manager.h>
#include <telepathy-glib/channel-request.h>
#include <telepathy-glib/channel.h>
#include <telepathy-glib/client.h>
#include <telepathy-glib/client-message.h>
#include <telepathy-glib/cm-message.h>
#include <telepathy-glib/connection-contact-list.h>
#include <telepathy-glib/connection-manager.h>
#include <telepathy-glib/connection.h>
#include <telepathy-glib/contact-operations.h>
#include <telepathy-glib/contact-search-result.h>
#include <telepathy-glib/contact-search.h>
#include <telepathy-glib/contact.h>
#include <telepathy-glib/dbus.h>
#include <telepathy-glib/dbus-tube-channel.h>
#include <telepathy-glib/debug-client.h>
#include <telepathy-glib/debug-message.h>
#include <telepathy-glib/debug-sender.h>
#include <telepathy-glib/debug.h>
#include <telepathy-glib/dtmf.h>
#include <telepathy-glib/file-transfer-channel.h>
#include <telepathy-glib/group-mixin.h>
#include <telepathy-glib/handle-channel-context.h>
#include <telepathy-glib/handle-repo.h>
#include <telepathy-glib/handle-repo-dynamic.h>
#include <telepathy-glib/handle-repo-static.h>
#include <telepathy-glib/handle.h>
#include <telepathy-glib/logger.h>
#include <telepathy-glib/message.h>
#include <telepathy-glib/message-mixin.h>
#include <telepathy-glib/observe-channel-context.h>
#include <telepathy-glib/presence-mixin.h>
#include <telepathy-glib/protocol.h>
#include <telepathy-glib/proxy.h>
#include <telepathy-glib/room-info.h>
#include <telepathy-glib/room-list.h>
#include <telepathy-glib/run.h>
#include <telepathy-glib/signalled-message.h>
#include <telepathy-glib/simple-approver.h>
#include <telepathy-glib/client-factory.h>
#include <telepathy-glib/simple-handler.h>
#include <telepathy-glib/simple-password-manager.h>
#include <telepathy-glib/simple-observer.h>
#include <telepathy-glib/stream-tube-channel.h>
#include <telepathy-glib/stream-tube-connection.h>
#include <telepathy-glib/text-channel.h>
#include <telepathy-glib/tls-certificate.h>
#include <telepathy-glib/variant-util.h>

#undef _TP_GLIB_H_INSIDE

#endif /* __TP_GLIB_H__ */
